
*** Exclude pp who do not own a smartphone


USE ALL.
COMPUTE filter_$=(smartphone ~= 2).
VARIABLE LABELS filter_$ 'smartphone ~= 2 (FILTER)'.
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'.
FORMATS filter_$ (f1.0).
FILTER BY filter_$.
EXECUTE.

*** Demographics

FREQUENCIES VARIABLES=gender
  /ORDER=ANALYSIS.

DESCRIPTIVES VARIABLES=age
  /STATISTICS=MEAN STDDEV MIN MAX.

*** Manipulation Check

T-TEST GROUPS=condition(0 1)
  /MISSING=ANALYSIS
  /VARIABLES=tempted
  /CRITERIA=CI(.95).

*** Manova - Effect of condition on reason acceptability

GLM frustratio workinghar gooddeed tuesday BY condition
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(OVERALL) 
  /PRINT=DESCRIPTIVE ETASQ OPOWER
  /CRITERIA=ALPHA(.05)
  /DESIGN= condition.


*** Compute a variable for mean reason acceptability

RELIABILITY
  /VARIABLES=frustratio workinghar gooddeed tuesday
  /SCALE('ALL VARIABLES') ALL
  /MODEL=ALPHA.

COMPUTE mean_reason=(frustratio + workinghar + gooddeed + tuesday) / 4.
EXECUTE.

*** Anova - Effect of condition on mean reason acceptability

UNIANOVA mean_reason BY condition
  /METHOD=SSTYPE(3)
  /INTERCEPT=INCLUDE
  /EMMEANS=TABLES(OVERALL) 
  /PRINT=OPOWER ETASQ DESCRIPTIVE
  /CRITERIA=ALPHA(.05)
  /DESIGN=condition.

*** Regressions to test the relation between temptingness of the phone and reason acceptability

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT frustratio
  /METHOD=ENTER tempted.

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT workinghar
  /METHOD=ENTER tempted.

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT gooddeed
  /METHOD=ENTER tempted.

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT tuesday
  /METHOD=ENTER tempted.

REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN 
  /DEPENDENT mean_reason
  /METHOD=ENTER tempted.


.



